@@ -161,19 +161,25 @@ class Queue(OrchestratorHTTP):
         # pprint(format_body_queue)
         return self._post(url, body=format_body_queue)
 
-    def _format_specific_content(self, queue_name, sp_content, priority="Low", progress="New", reference=None):
+    def _format_specific_content(self, queue_name, sp_content, priority="Low", progress="New", reference=None, batch_id=None):
+        ran_uuid = str(uuid4())
         formatted_sp_content = {
             "Name": queue_name,
             "Priority": priority,
             "SpecificContent": sp_content,
-            "Progress": progress
+            "Progress": progress,
+            "ReferenceID": ran_uuid
+
         }
-        ran_uuid = str(uuid4())
-        if reference:
-            ref_uuid = {"Reference": f"{sp_content[reference]}#{ran_uuid}"}
-            formatted_sp_content.update(ref_uuid)
-        else:
-            formatted_sp_content.update(ran_uuid)
+        try:
+            if reference:
+                ref_uuid = {"Reference": f"{sp_content[reference]}#{batch_id}"}
+                formatted_sp_content.update(ref_uuid)
+                formatted_sp_content.update({"ItemID": sp_content[reference]})
+            else:
+                formatted_sp_content.update({"Reference": batch_id})
+        except KeyError:
+            raise
 
         return formatted_sp_content
 
@@ -194,10 +200,12 @@ class Queue(OrchestratorHTTP):
         url = f"{self.base_url}{endpoint}{uipath_svc}"
         if not specific_contents:
             raise OrchestratorMissingParam(value="specific_contents", message="specific contents cannot be null")
+
+        batch_id = str(uuid4)
         format_body_queue = {
             "commitType": "StopOnFirstFailure",
             "queueName": self.name,
-            "queueItems": [self._format_specific_content(queue_name=self.name, sp_content=sp_content, priority=priority, progress=progress) for sp_content in specific_contents]
+            "queueItems": [self._format_specific_content(queue_name=self.name, sp_content=sp_content, priority=priority, progress=progress, reference=reference, batch_id=batch_id) for sp_content in specific_contents]
         }
         # pprint(format_body_queue)
         return self._post(url, body=format_body_queue)
